#pragma once

#include "integration/quadratureRules.h"
#include <assert.h>

namespace parfem {
  enum QuadratureType { GAUSS_LOBATTO=0, GAUSS_JACOBI=4, TRAPEZE=5 }; 

template<class ScalarT, int dim>
class Point {
private:
  Point() { }
};


template<class ScalarT, int dim>
class Quadrature
{
public:
  typedef Point<int, dim> IPointT;

  Quadrature(QuadratureType type, IPointT dims)
  {
    init(type, dims);
  }

  void init(QuadratureType type, IPointT dims)
  {
    switch(type) {
      case GAUSS_JACOBI: init<GAUSS_JACOBI>(dims);
      case GAUSS_LOBATTO: init<GAUSS_LOBATTO>(dims);

    default:
      assert(false);
    }
  }


  template<QuadratureType type>
  void init(IPointT dims);

  };

}
